@@ -1,7 +1,7 @@
 // SPDX-FileCopyrightText: 2021 Alexander Lohnau <alexander.lohnau@gmx.de>
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <qplugin.h>
+#include <QObject>
 #include "macros.h"
 
 #include "cursorcreator.h"
